appkit.rum


adapt-classcljs

(adapt-class react-class)
source

kebab-case->camel-caseclj/s

(kebab-case->camel-case input)

Converts from kebab case to camel case, eg: on-click to onClick

Converts from kebab case to camel case, eg: on-click to onClick
sourceraw docstring

map-keys->camel-caseclj/s

(map-keys->camel-case data & {:keys [html-props]})

Stringifys all the keys of a cljs hashmap and converts them from kebab case to camel case. If :html-props option is specified, then rename the html properties values to their dom equivalent before conversion

Stringifys all the keys of a cljs hashmap and converts them
from kebab case to camel case. If :html-props option is specified,
then rename the html properties values to their dom equivalent
before conversion
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries